@@ -23,7 +23,7 @@
 #include <glib/gi18n.h>
 
 #include "gedit-app.h"
-#include "gedit-commands.h"
+#include "gedit-commands-private.h"
 #include "gedit-multi-notebook.h"
 
 struct _GeditNotebookPopupMenuPrivate
