@@ -27,9 +27,6 @@
 
 G_BEGIN_DECLS
 
-/*
- * Type checking and casting macros
- */
 #define GEDIT_TYPE_PRINT_JOB              (gedit_print_job_get_type())
 #define GEDIT_PRINT_JOB(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GEDIT_TYPE_PRINT_JOB, GeditPrintJob))
 #define GEDIT_PRINT_JOB_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GEDIT_TYPE_PRINT_JOB, GeditPrintJobClass))
@@ -37,13 +34,14 @@ G_BEGIN_DECLS
 #define GEDIT_IS_PRINT_JOB_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GEDIT_TYPE_PRINT_JOB))
 #define GEDIT_PRINT_JOB_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GEDIT_TYPE_PRINT_JOB, GeditPrintJobClass))
 
+typedef struct _GeditPrintJob		GeditPrintJob;
+typedef struct _GeditPrintJobClass	GeditPrintJobClass;
+typedef struct _GeditPrintJobPrivate	GeditPrintJobPrivate;
 
 typedef enum
 {
-	GEDIT_PRINT_JOB_STATUS_INIT,
 	GEDIT_PRINT_JOB_STATUS_PAGINATING,
-	GEDIT_PRINT_JOB_STATUS_DRAWING,
-	GEDIT_PRINT_JOB_STATUS_DONE
+	GEDIT_PRINT_JOB_STATUS_DRAWING
 } GeditPrintJobStatus;
 
 typedef enum
@@ -53,15 +51,6 @@ typedef enum
 	GEDIT_PRINT_JOB_RESULT_ERROR
 } GeditPrintJobResult;
 
-/* Private structure type */
-typedef struct _GeditPrintJobPrivate GeditPrintJobPrivate;
-
-/*
- * Main object structure
- */
-typedef struct _GeditPrintJob GeditPrintJob;
-
-
 struct _GeditPrintJob
 {
 	GObject parent;
@@ -70,11 +59,6 @@ struct _GeditPrintJob
 	GeditPrintJobPrivate *priv;
 };
 
-/*
- * Class definition
- */
-typedef struct _GeditPrintJobClass GeditPrintJobClass;
-
 struct _GeditPrintJobClass
 {
 	GObjectClass parent_class;
@@ -86,21 +70,15 @@ struct _GeditPrintJobClass
 	void (* show_preview)	(GeditPrintJob       *job,
 				 GtkWidget           *preview);
 
-        void (*done)		(GeditPrintJob       *job,
+        void (* done)		(GeditPrintJob       *job,
         			 GeditPrintJobResult  result,
         			 const GError        *error);
 };
 
-/*
- * Public methods
- */
 GType			 gedit_print_job_get_type		(void) G_GNUC_CONST;
 
 GeditPrintJob		*gedit_print_job_new			(GeditView                *view);
 
-void			 gedit_print_job_set_export_filename	(GeditPrintJob            *job,
-								 const gchar              *filename);
-
 GtkPrintOperationResult	 gedit_print_job_print			(GeditPrintJob            *job,
 								 GtkPrintOperationAction   action,
 								 GtkPageSetup             *page_setup,
